import{x as s,ae as m,c as n,R as e,y as l,D as c,n as u,I as f}from"./index-DuDRe8hE.js";import{I as h}from"./ItemsListing-Cd5IBPUO.js";import"./ItemContextMenu.vue_vue_type_style_index_0_scoped_ea20d839_lang-Cfo9s-Sj.js";import"./ProviderIcon.vue_vue_type_script_setup_true_lang-CHFYJo9W.js";import"./VListItem-CuoSvcqW.js";import"./VChip-BRQkwjNJ.js";import"./VList-BlpguAX2.js";import"./VCardText-Dn8Yf3BC.js";import"./VCard-Cf5RelEw.js";import"./VMenu-B49kEbTj.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./eventbus-CGRXT3Tn.js";import"./ListItem-xrpNnThP.js";import"./VCheckbox-DBOdVsut.js";import"./VCheckboxBtn-CMIUd74V.js";import"./VTooltip-aHjUkPs6.js";import"./VSpacer-CYzCqmAo.js";/* empty css              */import"./PanelviewItemCompact-BQvk3oJ_.js";import"./Container-CQhyPPl2.js";import"./VContainer-CCoTeKDA.js";import"./Toolbar-CibNv11m.js";import"./VToolbar-Dhcm-C4i.js";import"./VTextField-D5EFKWzi.js";import"./VInfiniteScroll-BaRPR-8K.js";import"./layout-qserhqCM.js";import"./VRow-C-co90yO.js";import"./VVirtualScroll-CdwGYB7u.js";import"./VAlert-sqJ4UeFM.js";const Q=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:o}=m(),p=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),a=async function(r){return await f.browse(t.path)};return(r,w)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":a,"sort-keys":["original","name","name_desc"],title:p.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{Q as default};
