import{a as k,i as b,o as h,G as C,w as A,j as g,m as M,l as G,b as J,Y as K,H as Q,I as U,c as Y,Z,d as $,J as z,U as W,u as X,L as ee,q as ae,n as te,f as ne,_ as de,Q as ie,K as le,g as se,$ as ce,V as re,a0 as ue,N as ve}from"./VListItem-CuoSvcqW.js";import{g as f,l as oe,n,p as S,aO as u,F as p,f as me,i as ye,c as P,a9 as ge,aa as ke,q as be}from"./index-DuDRe8hE.js";import{V as fe,a as Ie,b as Ve}from"./VCardText-Dn8Yf3BC.js";const Ce=f()({name:"VCardActions",props:k(),setup(e,i){let{slots:t}=i;return oe({VBtn:{slim:!0,variant:"text"}}),b(()=>{var a;return n("div",{class:["v-card-actions",e.class],style:e.style},[(a=t.default)==null?void 0:a.call(t)])}),{}}}),Ae=S({appendAvatar:String,appendIcon:u,prependAvatar:String,prependIcon:u,subtitle:[String,Number],title:[String,Number],...k(),...h()},"VCardItem"),pe=f()({name:"VCardItem",props:Ae(),setup(e,i){let{slots:t}=i;return b(()=>{var s;const a=!!(e.prependAvatar||e.prependIcon),v=!!(a||t.prepend),l=!!(e.appendAvatar||e.appendIcon),o=!!(l||t.append),m=!!(e.title!=null||t.title),y=!!(e.subtitle!=null||t.subtitle);return n("div",{class:["v-card-item",e.class],style:e.style},[v&&n("div",{key:"prepend",class:"v-card-item__prepend"},[t.prepend?n(g,{key:"prepend-defaults",disabled:!a,defaults:{VAvatar:{density:e.density,image:e.prependAvatar},VIcon:{density:e.density,icon:e.prependIcon}}},t.prepend):n(p,null,[e.prependAvatar&&n(C,{key:"prepend-avatar",density:e.density,image:e.prependAvatar},null),e.prependIcon&&n(A,{key:"prepend-icon",density:e.density,icon:e.prependIcon},null)])]),n("div",{class:"v-card-item__content"},[m&&n(fe,{key:"title"},{default:()=>{var d;return[((d=t.title)==null?void 0:d.call(t))??e.title]}}),y&&n(Ie,{key:"subtitle"},{default:()=>{var d;return[((d=t.subtitle)==null?void 0:d.call(t))??e.subtitle]}}),(s=t.default)==null?void 0:s.call(t)]),o&&n("div",{key:"append",class:"v-card-item__append"},[t.append?n(g,{key:"append-defaults",disabled:!l,defaults:{VAvatar:{density:e.density,image:e.appendAvatar},VIcon:{density:e.density,icon:e.appendIcon}}},t.append):n(p,null,[e.appendIcon&&n(A,{key:"append-icon",density:e.density,icon:e.appendIcon},null),e.appendAvatar&&n(C,{key:"append-avatar",density:e.density,image:e.appendAvatar},null)])])])}),{}}}),Pe=S({appendAvatar:String,appendIcon:u,disabled:Boolean,flat:Boolean,hover:Boolean,image:String,link:{type:Boolean,default:void 0},prependAvatar:String,prependIcon:u,ripple:{type:[Boolean,Object],default:!0},subtitle:[String,Number],text:[String,Number],title:[String,Number],...M(),...k(),...h(),...G(),...J(),...K(),...Q(),...U(),...Y(),...Z(),...$(),...me(),...z({variant:"elevated"})},"VCard"),Le=f()({name:"VCard",directives:{Ripple:W},props:Pe(),setup(e,i){let{attrs:t,slots:a}=i;const{themeClasses:v}=ye(e),{borderClasses:l}=X(e),{colorClasses:o,colorStyles:m,variantClasses:y}=ee(e),{densityClasses:s}=ae(e),{dimensionStyles:d}=te(e),{elevationClasses:x}=ne(e),{loaderClasses:L}=de(e),{locationStyles:T}=ie(e),{positionClasses:_}=le(e),{roundedClasses:B}=se(e),c=ce(e,t),D=P(()=>e.link!==!1&&c.isLink.value),r=P(()=>!e.disabled&&e.link!==!1&&(e.link||c.isClickable.value));return b(()=>{const N=D.value?"a":e.tag,R=!!(a.title||e.title!=null),F=!!(a.subtitle||e.subtitle!=null),O=R||F,j=!!(a.append||e.appendAvatar||e.appendIcon),q=!!(a.prepend||e.prependAvatar||e.prependIcon),w=!!(a.image||e.image),E=O||q||j,H=!!(a.text||e.text!=null);return ge(n(N,be({class:["v-card",{"v-card--disabled":e.disabled,"v-card--flat":e.flat,"v-card--hover":e.hover&&!(e.disabled||e.flat),"v-card--link":r.value},v.value,l.value,o.value,s.value,x.value,L.value,_.value,B.value,y.value,e.class],style:[m.value,d.value,T.value,e.style],onClick:r.value&&c.navigate,tabindex:e.disabled?-1:void 0},c.linkProps),{default:()=>{var I;return[w&&n("div",{key:"image",class:"v-card__image"},[a.image?n(g,{key:"image-defaults",disabled:!e.image,defaults:{VImg:{cover:!0,src:e.image}}},a.image):n(re,{key:"image-img",cover:!0,src:e.image},null)]),n(ue,{name:"v-card",active:!!e.loading,color:typeof e.loading=="boolean"?void 0:e.loading},{default:a.loader}),E&&n(pe,{key:"item",prependAvatar:e.prependAvatar,prependIcon:e.prependIcon,title:e.title,subtitle:e.subtitle,appendAvatar:e.appendAvatar,appendIcon:e.appendIcon},{default:a.item,prepend:a.prepend,title:a.title,subtitle:a.subtitle,append:a.append}),H&&n(Ve,{key:"text"},{default:()=>{var V;return[((V=a.text)==null?void 0:V.call(a))??e.text]}}),(I=a.default)==null?void 0:I.call(a),a.actions&&n(Ce,null,{default:a.actions}),ve(r.value,"v-card")]}}),[[ke("ripple"),r.value&&e.ripple]])}),{}}});export{Le as V,Ce as a,pe as b};
