import{p as g,g as D,k as M,x as P,aa as S,y as t,z as o,A as s,a9 as I,q as X,a2 as C,n as c,K as p,B as w,G as d,M as A,D as h,J as r,aD as Y,S as k,ak as N,X as O,H as T}from"./index-DuDRe8hE.js";import{M as $}from"./ItemContextMenu.vue_vue_type_style_index_0_scoped_ea20d839_lang-Cfo9s-Sj.js";import{V as z}from"./VCard-Cf5RelEw.js";import{m as H,a as L,e as _}from"./VMenu-B49kEbTj.js";import{V as E}from"./VCheckbox-DBOdVsut.js";import{D as F,E as b,k as q,v as G}from"./VListItem-CuoSvcqW.js";import{_ as J}from"./_plugin-vue_export-helper-DlAUqK2U.js";const K=g({disabled:Boolean,modelValue:{type:Boolean,default:null},...H()},"VHover"),R=D()({name:"VHover",props:K(),emits:{"update:modelValue":i=>!0},setup(i,f){let{slots:a}=f;const l=M(i,"modelValue"),{runOpenDelay:m,runCloseDelay:y}=L(i,n=>!i.disabled&&(l.value=n));return()=>{var n;return(n=a.default)==null?void 0:n.call(a,{isHovering:l.value,props:{onMouseenter:m,onMouseleave:y}})}}}),j=["model-value"],Q={key:0},U={key:1},W={key:2},Z=P({__name:"PanelviewItemCompact",props:{item:{},size:{default:200},isSelected:{type:Boolean,default:!1},showCheckboxes:{type:Boolean,default:!1},permanentOverlay:{type:Boolean,default:!1},isAvailable:{type:Boolean,default:!0}},emits:["menu","click","play","select"],setup(i,{emit:f}){const a=i,l=f,m=function(e){if(a.showCheckboxes)return;const V="clientX"in e?e.clientX:e.touches[0].clientX,v="clientY"in e?e.clientY:e.touches[0].clientY;l("menu",a.item,V,v)},y=function(e){if(a.showCheckboxes){l("select",a.item,!a.isSelected);return}l("click",a.item,e.clientX,e.clientY)},n=function(e){a.showCheckboxes||l("play",a.item,e.clientX,e.clientY)};return(e,V)=>{const v=S("hold");return t(),o(R,null,{default:s(({isHovering:u,props:B})=>[I((t(),o(z,X(B,{class:{"on-hover":u,unavailable:!e.isAvailable},elevation:u?3:0,onClick:y,onContextmenu:C(m,["right","prevent"])}),{default:s(()=>[e.showCheckboxes?(t(),o(_,{key:0,"model-value":e.showCheckboxes,contained:"",scrim:e.isSelected?e.$vuetify.theme.current.dark?"rgba(0,0,0,.75)":"rgba(255,255,255,.75)":"#ffffff00"},{default:s(()=>[c(E,{class:"panel-item-checkbox",ripple:!1,"model-value":e.isSelected},null,8,["model-value"])]),_:1},8,["model-value","scrim"])):p("",!0),c($,{item:e.isAvailable?e.item:void 0},null,8,["item"]),w("div",{class:O(e.$vuetify.theme.current.dark?"paneldetails-dark":"paneldetails"),"model-value":u||e.$vuetify.display.mobile||e.permanentOverlay},[c(q,{variant:"text",slim:"",tile:"",density:"compact",class:"panel-item-details"},{default:s(()=>[c(F,null,{default:s(()=>[e.item.media_type==d(A).FOLDER?(t(),h("span",Q,[w("span",null,r(d(Y)(e.item,e.$t)),1)])):(t(),h("span",U,r(e.item.name),1)),"version"in e.item&&e.item.version?(t(),h("span",W," - "+r(e.item.version),1)):p("",!0)]),_:1}),"artists"in e.item&&e.item.artists?(t(),o(b,{key:0,class:"line-clamp-1"},{default:s(()=>[k(r(d(N)(e.item.artists,1)),1)]),_:1})):"owner"in e.item&&e.item.owner?(t(),o(b,{key:1,class:"line-clamp-1"},{default:s(()=>[k(r(e.item.owner),1)]),_:1})):"provider_mappings"in e.item?p("",!0):(t(),o(b,{key:2,class:"line-clamp-1"},{default:s(()=>[k(r(e.$t(e.item.media_type)),1)]),_:1}))]),_:1})],10,j),(u||d(T).isTouchscreen)&&e.isAvailable?(t(),o(G,{key:1,icon:"mdi-play",color:"primary",fab:"",size:"small",style:{position:"absolute",right:"10px",bottom:"35px",opacity:"0.8"},onClick:C(n,["stop"])})):p("",!0)]),_:2},1040,["class","elevation"])),[[v,m]])]),_:1})}}}),ie=J(Z,[["__scopeId","data-v-5a402c67"]]);export{ie as P,R as V};
